Skip to contents

The 'pqverse' is a set of packages for metabarcoding analysis that share the phyloseq object as their central data structure. This package makes it easy to install and load multiple 'pqverse' packages in a single step.

Author

Maintainer: Adrien Taudière adrien.taudiere@zaclys.net (ORCID)

Authors: